==> pf4-component-mapper-3.4.1.tgz: package/esm/tabs/tabs.js <==
import _extends from "@babel/runtime/helpers/extends";
import _slicedToArray from "@babel/runtime/helpers/slicedToArray";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import React, { useState } from 'react';
import PropTypes from 'prop-types';
import useFormApi from "@data-driven-forms/react-form-renderer/use-form-api";
import { Tab } from "@patternfly/react-core/dist/esm/components/Tabs/Tab.js";
import { Tabs } from "@patternfly/react-core/dist/esm/components/Tabs/Tabs.js";
import { TabTitleText } from "@patternfly/react-core/dist/esm/components/Tabs/TabTitleText.js";

var FormTabs = function FormTabs(_ref) {
  var fields = _ref.fields,
      dataType = _ref.dataType,
      validate = _ref.validate,
      component = _ref.component,
      rest = _objectWithoutProperties(_ref, ["fields", "dataType", "validate", "component"]);

  var formOptions = useFormApi();

  var _useState = useState(0),
      _useState2 = _slicedToArray(_useState, 2),
      activeTabKey = _useState2[0],
      setActiveTabKey = _useState2[1];

  var handleTabClick = function handleTabClick(event, tabIndex) {
    event.preventDefault();
    setActiveTabKey(tabIndex);
  };

  var renderTabItems = function renderTabItems(fields) {
    return fields.map(function (_ref2, index) {
      var fields = _ref2.fields,
          title = _ref2.title,
          name = _ref2.name;
      return /*#__PURE__*/React.createElement(Tab, {
        key: name,
        eventKey: index,
        title: typeof title === 'string' ? /*#__PURE__*/React.createElement(TabTitleText, null, title) : title
      }, /*#__PURE__*/React.createElement("div", {
        className: "pf-c-form"
      }, formOptions.renderForm(fields, formOptions)));
    });
  };

  return /*#__PURE__*/React.createElement(Tabs, _extends({
    activeKey: activeTabKey,
    onSelect: handleTabClick
  }, rest), renderTabItems(fields, formOptions));
};

FormTabs.propTypes = {
  fields: PropTypes.array.isRequired,
  dataType: PropTypes.any,
  validate: PropTypes.any,
  component: PropTypes.any
};
export default FormTabs;

==> pf4-component-mapper-3.16.0.tgz: package/esm/tabs/tabs.js <==
import _extends from "@babel/runtime/helpers/extends";
import _slicedToArray from "@babel/runtime/helpers/slicedToArray";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["fields", "dataType", "validate", "component"];
import React, { useState } from 'react';
import PropTypes from 'prop-types';
import useFormApi from "@data-driven-forms/react-form-renderer/use-form-api";
import { Tab } from "@patternfly/react-core/dist/esm/components/Tabs/Tab.js";
import { Tabs } from "@patternfly/react-core/dist/esm/components/Tabs/Tabs.js";
import { TabTitleText } from "@patternfly/react-core/dist/esm/components/Tabs/TabTitleText.js";

var FormTabs = function FormTabs(_ref) {
  var fields = _ref.fields,
      dataType = _ref.dataType,
      validate = _ref.validate,
      component = _ref.component,
      rest = _objectWithoutProperties(_ref, _excluded);

  var formOptions = useFormApi();

  var _useState = useState(0),
      _useState2 = _slicedToArray(_useState, 2),
      activeTabKey = _useState2[0],
      setActiveTabKey = _useState2[1];

  var handleTabClick = function handleTabClick(event, tabIndex) {
    event.preventDefault();
    setActiveTabKey(tabIndex);
  };

  var renderTabItems = function renderTabItems(fields) {
    return fields.map(function (_ref2, index) {
      var fields = _ref2.fields,
          title = _ref2.title,
          name = _ref2.name;
      return /*#__PURE__*/React.createElement(Tab, {
        key: name,
        eventKey: index,
        title: typeof title === 'string' ? /*#__PURE__*/React.createElement(TabTitleText, null, title) : title
      }, /*#__PURE__*/React.createElement("div", {
        className: "pf-c-form"
      }, formOptions.renderForm(fields, formOptions)));
    });
  };

  return /*#__PURE__*/React.createElement(Tabs, _extends({
    activeKey: activeTabKey,
    onSelect: handleTabClick
  }, rest), renderTabItems(fields, formOptions));
};

FormTabs.propTypes = {
  fields: PropTypes.array.isRequired,
  dataType: PropTypes.any,
  validate: PropTypes.any,
  component: PropTypes.any
};
export default FormTabs;
